@@ -205,11 +205,15 @@ def p_package_options(t):
 
 def p_files(t):
     '''files : empty
-             | PLUS NOSPACESTRING files'''
+             | PLUS NOSPACESTRING files
+             | PLUS ATOM NOSPACESTRING files'''
     if len(t) == 2:
         t[0] = []
     elif len(t) == 4:
         t[0] = [t[2]] + t[3]
+    elif len(t) == 5:
+        if t[2] in t.parser.tags:
+            t[0] = [t[2]] + t[3]
     else:
         assert False
 
